@@ -22,9 +22,10 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     RegressionAlgorithmsCP4D, ForecastingAlgorithmsCP4D, SamplingTypes, ImputationStrategy)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel, \
     NonForecastPredictionColumnMissing, ForecastPredictionColumnsMissing, ForecastingCannotBeRunAsLocalScenario, \
-    TSNotSupported, ParamOutOfRange
+    TSNotSupported, ParamOutOfRange, ImputationListNotSupported
 from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
-    validate_additional_params_for_optimizer, validate_optimizer_enum_values
+    validate_additional_params_for_optimizer, validate_optimizer_enum_values, \
+    translate_imputation_string_strategy_to_enum
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -406,8 +407,10 @@ class AutoAI(BaseExperiment):
             raise TSNotSupported()
 
         if prediction_type == PredictionType.FORECASTING:
-            if not numerical_imputation_strategy:
+            if not numerical_imputation_strategy and type(numerical_imputation_strategy) is not list:
                 numerical_imputation_strategy = ImputationStrategy.BEST_OF_DEFAULT_IMPUTERS
+            elif not numerical_imputation_strategy and type(numerical_imputation_strategy) is list:
+                numerical_imputation_strategy = ImputationStrategy.NO_IMPUTATION
 
             if prediction_column is not None or prediction_columns is None:
                 raise ForecastPredictionColumnsMissing()
@@ -427,12 +430,24 @@ class AutoAI(BaseExperiment):
                 include_only_estimators = daub_include_only_estimators
             daub_include_only_estimators = None
 
+        def translate_str_imputation_param(x):
+            if type(x) is list and prediction_type != PredictionType.FORECASTING:
+                raise ImputationListNotSupported()
+
+            if type(x) == str or (type(x) == list and type(x[0]) == str):
+                return translate_imputation_string_strategy_to_enum(x, prediction_type)
+            else:
+                return x
+
+        categorical_imputation_strategy = translate_str_imputation_param(categorical_imputation_strategy)
+        numerical_imputation_strategy = translate_str_imputation_param(numerical_imputation_strategy)
+
         validate_optimizer_enum_values(
             prediction_type=prediction_type,
             daub_include_only_estimators=daub_include_only_estimators,
             include_only_estimators=include_only_estimators,
             cognito_transform_names=cognito_transform_names,
-            imputation_strategies=list(filter(None, [categorical_imputation_strategy, numerical_imputation_strategy])),
+            imputation_strategies=[x for y in list(filter(None, [categorical_imputation_strategy, numerical_imputation_strategy])) for x in (y if type(y) is list else [y])],
             scoring=scoring,
             t_shirt_size=kwargs.get("t_shirt_size", TShirtSize.M),
             is_cpd=self._workspace.wml_client.ICP
