@@ -12,7 +12,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 import json
 import base64
 import logging
@@ -200,7 +200,7 @@ class ServiceInstance:
                 return token
             else:
                 token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
-                response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
+                response = requests.get(token_url, auth=(self.get_username(), self.get_password()))
 
                 if response.status_code == 200:
                     token = response.json().get(u'accessToken')
@@ -209,7 +209,7 @@ class ServiceInstance:
                 return token
 
     def _refresh_token(self):
-        import requests
+        import ibm_watson_machine_learning._wrappers.requests as requests
         if self._client.proceed is True:
             self._client.wml_token = self._wml_credentials["token"]
         else:
@@ -230,7 +230,7 @@ class ServiceInstance:
                     raise ApiRequestFailure(u'Error during refreshing ML Token.', response)
             else:
                 token_url = self._wml_credentials['url'].replace(':31002', ':31843') + '/v1/preauth/validateAuth'
-                response = requests.get(token_url, auth=(self.get_username(), self.get_password()), verify=False)
+                response = requests.get(token_url, auth=(self.get_username(), self.get_password()))
 
                 if response.status_code == 200:
                     self._client.wml_token = response.json().get(u'accessToken')
@@ -280,7 +280,7 @@ class ServiceInstance:
             'Content-type' :'application/json',
             'cache-control': 'no-cache'
         }
-        response = requests.post(token_url, auth=(self.get_username(), self.get_password()), verify=False)
+        response = requests.post(token_url, auth=(self.get_username(), self.get_password()))
         if response.status_code == 200:
             print(response)
             token = response.json().get(u'token')
