@@ -374,8 +374,11 @@ class SWSReceiver(FLReceiver):
 
         else:
 
-            if recv_msg.sender_info is not None and recv_msg.sender_info == self.party:
-                logger.debug("Received Message is reply to previously sent message")
+            if recv_msg.sender_info is not None:
+                if recv_msg.sender_info == self.party:
+                    logger.debug("Received Message is reply to previously sent message")
+                else:
+                    logger.warning("Received Message is reply for message from "+recv_msg.sender_info)
                 return
                 
             try:
