@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from __future__ import print_function
-import requests
+import ibm_watson_machine_learning._wrappers.requests as requests
 requests.packages.urllib3.disable_warnings()
 import json
 import os
@@ -177,7 +177,7 @@ class Runtimes(WMLResource):
                                               headers=self._client._get_headers())
             else:
                 response_post = requests.post(self._client.service_instance._href_definitions.get_custom_libraries_href(), json=lib_metadata,
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
             details = self._handle_response(201, u'saving libraries', response_post)
 
             if self.LibraryMetaNames.FILEPATH in meta_props:
@@ -187,11 +187,7 @@ class Runtimes(WMLResource):
 
                     put_header = self._client._get_headers(no_content_type=True)
                     with open(meta_props[self.LibraryMetaNames.FILEPATH], 'rb') as data:
-                        if not self._ICP:
-                            response_definition_put = requests.put(libraries_content_url, data=data, headers=put_header)
-                        else:
-                            response_definition_put = requests.put(libraries_content_url, data=data, headers=put_header,
-                                                                   verify=False)
+                        response_definition_put = requests.put(libraries_content_url, data=data, headers=put_header)
 
                 except Exception as e:
                     raise e
@@ -243,7 +239,7 @@ class Runtimes(WMLResource):
                                               headers=self._client._get_headers())
             else:
                 response_post = requests.post(self._client.service_instance._href_definitions.get_runtimes_href(), json=metadata,
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
             details = self._handle_response(201, u'saving runtimes', response_post)
             if self.ConfigurationMetaNames.CONFIGURATION_FILEPATH in meta_props:
                 try:
@@ -251,11 +247,7 @@ class Runtimes(WMLResource):
 
                     put_header = self._client._get_headers(content_type="text/plain")
                     with open(meta_props[self.ConfigurationMetaNames.CONFIGURATION_FILEPATH], 'rb') as data:
-                        if not self._ICP:
-                            response_definition_put = requests.put(runtimes_content_url, data=data,headers=put_header)
-                        else:
-                            response_definition_put = requests.put(runtimes_content_url, data=data,headers=put_header,
-                                                                   verify=False)
+                        response_definition_put = requests.put(runtimes_content_url, data=data,headers=put_header)
 
                 except Exception as e:
                     raise e
@@ -620,15 +612,9 @@ class Runtimes(WMLResource):
 
         url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid)
 
-        if not self._ICP:
-            response_delete = requests.delete(
-                url,
-                headers=self._client._get_headers())
-        else:
-            response_delete = requests.delete(
-                url,
-                headers=self._client._get_headers(),
-                verify=False)
+        response_delete = requests.delete(
+            url,
+            headers=self._client._get_headers())
 
 
         if with_libraries:
@@ -666,7 +652,7 @@ class Runtimes(WMLResource):
                 if not self._ICP:
                     response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
                 else:
-                    response_delete = requests.delete(library_endpoint, headers=self._client._get_headers(), verify=False)
+                    response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
 
                 try:
                     self._handle_response(204, u'library deletion', response_delete, False)
@@ -705,7 +691,7 @@ class Runtimes(WMLResource):
         if not self._ICP:
             response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
         else:
-            response_delete = requests.delete(library_endpoint, headers=self._client._get_headers(), verify=False)
+            response_delete = requests.delete(library_endpoint, headers=self._client._get_headers())
 
         return self._handle_response(204, u'library deletion', response_delete, False)
 
@@ -868,15 +854,9 @@ class Runtimes(WMLResource):
 
         download_url = self._client.service_instance._href_definitions.get_runtime_href(runtime_uid) + '/content'
 
-        if not self._ICP:
-            response_get = requests.get(
-                download_url,
-                headers=self._client._get_headers())
-        else:
-            response_get = requests.get(
-                download_url,
-                headers=self._client._get_headers(),
-                verify=False)
+        response_get = requests.get(
+            download_url,
+            headers=self._client._get_headers())
 
         if filename is None:
             filename = 'runtime_configuration.yaml'
@@ -936,15 +916,9 @@ class Runtimes(WMLResource):
 
         download_url = self._client.service_instance._href_definitions.get_custom_library_href(library_uid) + '/content'
 
-        if not self._ICP:
-            response_get = requests.get(
-                download_url,
-                headers=self._client._get_headers())
-        else:
-            response_get = requests.get(
-                download_url,
-                headers=self._client._get_headers(),
-                verify=False)
+        response_get = requests.get(
+            download_url,
+            headers=self._client._get_headers())
 
         if filename is None:
             details = self.get_library_details(library_uid)
@@ -1003,7 +977,7 @@ class Runtimes(WMLResource):
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         else:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers(), verify=False)
+            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         updated_details = self._handle_response(200, u'library patch', response)
 
         return updated_details
@@ -1051,7 +1025,7 @@ class Runtimes(WMLResource):
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         else:
-            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers(), verify=False)
+            response = requests.patch(url, json=patch_payload, headers=self._client._get_headers())
         updated_details = self._handle_response(200, u'library patch', response)
 
         return updated_details
@@ -1119,7 +1093,7 @@ class Runtimes(WMLResource):
                                               headers=self._client._get_headers())
         else:
             response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning runtime',
                                             response=response_post)
@@ -1188,7 +1162,7 @@ class Runtimes(WMLResource):
                                               headers=self._client._get_headers())
         else:
             response_post = requests.post(url, json=clone_meta,
-                                              headers=self._client._get_headers(), verify=False)
+                                              headers=self._client._get_headers())
 
         details = self._handle_response(expected_status_code=200, operationName=u'cloning library',
                                             response=response_post)
