@@ -34,7 +34,8 @@ __all__ = [
     'validate_optimizer_enum_values',
     'all_logging_disabled',
     'check_if_ts_pipeline_is_winner',
-    'get_values_for_imputation_strategy'
+    'get_values_for_imputation_strategy',
+    'translate_imputation_string_strategy_to_enum'
 ]
 
 #  (C) Copyright IBM Corp. 2021.
@@ -57,6 +58,7 @@ import os
 import enum
 import gzip
 import inspect
+import re
 from contextlib import redirect_stdout
 from functools import wraps
 from subprocess import check_call
@@ -79,7 +81,7 @@ from .enums import (RegressionAlgorithms, RegressionAlgorithmsCP4D, Classificati
 from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
                      VisualizationFailed, AdditionalParameterIsUnexpected, InvalidSequenceValue, NoAvailableMetrics,
-                     DiscardedModel, WrongModelName, StrategyIsNotApplicable)
+                     DiscardedModel, WrongModelName, StrategyIsNotApplicable, InconsistentImputationListElements)
 
 if TYPE_CHECKING:
     from io import BytesIO, BufferedIOBase
@@ -1910,7 +1912,7 @@ def check_if_ts_pipeline_is_winner(details: dict, model_name: str) -> None:
                 raise DiscardedModel(model_name)
 
 
-def get_values_for_imputation_strategy(strategy, prediction_type):
+def get_values_for_imputation_strategy(strategy, prediction_type, imputer_fill_value=None):
     values = {ImputationStrategy.MEAN: {'kb': 'mean',
                                         'ts': {'use_imputation': True,
                                                'imputer_list': ['Fill'],
@@ -1925,7 +1927,7 @@ def get_values_for_imputation_strategy(strategy, prediction_type):
               ImputationStrategy.VALUE: {'ts': {'use_imputation': True,
                                                 'imputer_list': ['Fill'],
                                                 'imputer_fill_type': 'value',
-                                                'imputer_fill_value': 0}},
+                                                'imputer_fill_value': imputer_fill_value if imputer_fill_value else 0}},
               ImputationStrategy.FLATTEN_ITERATIVE: {'ts': {'use_imputation': True,
                                                             'imputer_list': ['FlattenIterative']}},
               ImputationStrategy.LINEAR: {'ts': {'use_imputation': True,
@@ -1938,6 +1940,35 @@ def get_values_for_imputation_strategy(strategy, prediction_type):
                                                'imputer_list': ['Next']}},
               ImputationStrategy.NO_IMPUTATION: {'ts': {'use_imputation': False}}}
 
+    if type(strategy) is list: # only for ts, checked earlier
+        results = [get_values_for_imputation_strategy(x, prediction_type, imputer_fill_value) for x in strategy]
+
+        def chose_strategies(res_elements):
+            indexes = [results.index(el) for el in res_elements]
+            return [strategy[i] for i in indexes]
+
+        no_imputation_res = list(filter(lambda x: not x['use_imputation'], results))
+        if any(no_imputation_res) and len(strategy) > len(no_imputation_res):
+            raise InconsistentImputationListElements(chose_strategies(no_imputation_res))
+
+        result = {'use_imputation': results[0]['use_imputation'],
+                  'imputer_list': [x for r in results for x in r['imputer_list']]}
+
+        fill_type_imputation_res = list(filter(lambda x: 'imputer_fill_type' in x, results))
+        fill_value_imputation_res = list(filter(lambda x: 'imputer_fill_value' in x, results))
+
+        if len(fill_type_imputation_res) > 1:
+            raise InconsistentImputationListElements(chose_strategies(fill_type_imputation_res))
+        elif len(fill_type_imputation_res) == 1:
+            result['imputer_fill_type'] = fill_type_imputation_res[0]['imputer_fill_type']
+
+        if len(fill_value_imputation_res) > 1:
+            raise InconsistentImputationListElements(chose_strategies(fill_value_imputation_res))
+        elif len(fill_value_imputation_res) == 1:
+            result['imputer_fill_value'] = fill_type_imputation_res[0]['imputer_fill_value']
+
+        return result
+
     v = values[strategy]
 
     if prediction_type == PredictionType.FORECASTING:
@@ -1952,3 +1983,14 @@ def get_values_for_imputation_strategy(strategy, prediction_type):
             raise StrategyIsNotApplicable(strategy, prediction_type, l)
 
         return v['kb']
+
+
+def translate_imputation_string_strategy_to_enum(strategy, prediction_type):
+    if type(strategy) is list and prediction_type == PredictionType.FORECASTING:
+        if 'Fill' in strategy:
+            strategy.remove('Fill')
+        return [translate_imputation_string_strategy_to_enum(x, prediction_type) for x in strategy]
+
+    strategy = re.sub(r'(?<!^)(?=[A-Z])', '_', strategy).lower()
+
+    return ImputationStrategy(strategy)
